
--[[

The following is a list of specific skills that will be tracked for temporary morale, & buff/debuff tracking purposes.

The skills are stored with the following information:

	{Class Name, Skill Type*, Skill Name**, <Skill Info>}
	
			*  Note that we define a "Buff" as a skill that applies an effect to a player (or players),
			       whereas a "Benefit" is a skill that is used on a player (or players) but does not apply
			       any effect (eg: Rising/Ebbing Ire)
			** Skill names are stored in the locale files, see the relevant locale file for more info
	
	... additional <Skill Info> is specified for buffs: Whether or not the buff is a self-applied buff only
	
	... additional <Skill Info> is specified for debuffs: Skill Icon Name*, Debuff Duration**, {List of Conflicting Skills***}, If the skill cannot override itself, <Secondary Debuff Info>
			
			*   As found in the Resources folder
			**  Durations are specified in seconds; a duration of "nil" specifies a toggle skill (ie: does not expire)
			*** Skills that get overidden by the application of this skill (NB: all debuffs are assumed to override themselves),
					"daze" in this list means the skill breaks dazes/roots/fears without state break notification
						
			... where <Secondary Debuff Info> includes: Should the initial debuff be ignored, Secondary Debuff Name, Time until the seconday debuff is applied (nil or 0 means immediately)
	
]]--

local skillList = {
	
	-- 0) Temporary Morale Skills
	{"Captain","TempMorale",L.ShieldOfTheDunedainTM},
	
	{"Champion","TempMorale",L.TrueHeroicsTM},
	{"Champion","TempMorale",L.SuddenDefenceTM},
	
	{"Minstrel","TempMorale",L.StoryOfTheHammerhandTM},
	{"Minstrel","TempMorale",L.SongOfTheHammerhandTM},
	{"Minstrel","TempMorale",L.GiftOfTheHammerhandTM},
	
	{"RuneKeeper","TempMorale",L.WordOfExaltationTM},
	{"RuneKeeper","TempMorale",L.EssayOfExaltationTM},
	
	{"None","TempMorale",L.MartyrsFortitudeTM},
  {"None","TempMorale",L.FrostRingTM},
	
	-- 1) Burglar Skills
	{"Burglar","Buff",L.TouchAndGo,true},
	{"Burglar","Buff",L.KnivesOut,true},
	{"Burglar","Buff",L.Mischievous,true,true},
	{"Burglar","Buff",L.QuietKnife,true,true},
	{"Burglar","Buff",L.Gambler,true,true},
	{"Burglar","Buff",L.TheMischiefMaker,true},
	{"Burglar","Buff",L.TheQuietKnife,true},
	{"Burglar","Buff",L.TheGambler,true},
	{"Burglar","Buff",L.Feint,true},
	{"Burglar","Buff",L.ImprovedFeint,true},
	{"Burglar","Buff",L.ArmourOfTheUnseen,true},
	
	{"Burglar","Debuff",L.RevealWeakness,"rw",nil},
	{"Burglar","Debuff",L.Addle,"addle",30},
	{"Burglar","Debuff",L.TrickDisable,"disable",30,{L.TrickCounterDefence,L.TrickImprovedCounterDefence,L.TrickDustInTheEyes,L.TrickEnrage}},
	{"Burglar","Debuff",L.TrickCounterDefence,"cd",30,{L.TrickDisable,L.TrickImprovedCounterDefence,L.TrickDustInTheEyes,L.TrickEnrage}},
	{"Burglar","Debuff",L.TrickImprovedCounterDefence,"cd",30,{L.TrickDisable,L.TrickCounterDefence,L.TrickDustInTheEyes,L.TrickEnrage}}, -- TODO: find improved icon
	{"Burglar","Debuff",L.TrickDustInTheEyes,"dite",30,{L.TrickDisable,L.TrickCounterDefence,L.TrickImprovedCounterDefence,L.TrickEnrage,"daze"},nil,nil,L.Slowed,0},
	{"Burglar","Debuff",L.Slowed,"slowed",30},
	{"Burglar","Debuff",L.TrickEnrage,"enrage",30,{L.TrickDisable,L.TrickCounterDefence,L.TrickImprovedCounterDefence,L.TrickDustInTheEyes,"daze"}},
	{"Burglar","Debuff",L.ASmallSnag,"smallsnag",15,nil,nil,nil,L.ASmallSnag.." "..L.Root,0},
	{"Burglar","Debuff",L.QuiteASnag,"quiteasnag",30,nil,nil,nil,L.QuiteASnag.." "..L.Root,0},
	{"Burglar","Debuff",L.Confound,"confound",15,nil,nil,nil,L.Confound.." "..L.Daze,15},
	
	{"Burglar","Crowd Control",L.Confound.." "..L.Daze,"daze",30},
	{"Burglar","Crowd Control",L.Riddle,"daze",30},
	{"Burglar","Crowd Control",L.ImprovedRiddle,"daze",30},
	{"Burglar","Crowd Control",L.ASmallSnag.." "..L.Root,"root",15},
	{"Burglar","Crowd Control",L.QuiteASnag.." "..L.Root,"root",30},
	-- NB: stuns are included for Burglars only to make chain-stunning more convenient via a buffbar
	{"Burglar","Crowd Control",L.StartlingTwist,"stun",8,{L.TrickDisable,L.TrickCounterDefence,L.TrickImprovedCounterDefence,L.TrickDustInTheEyes,L.TrickEnrage}},
	{"Burglar","Crowd Control",L.ImprovedStartlingTwist,"stun",8,{L.TrickDisable,L.TrickCounterDefence,L.TrickImprovedCounterDefence,L.TrickDustInTheEyes,L.TrickEnrage}},
	{"Burglar","Crowd Control",L.AdvancedStartlingTwist,"stun",8,{L.TrickDisable,L.TrickCounterDefence,L.TrickImprovedCounterDefence,L.TrickDustInTheEyes,L.TrickEnrage}},
	{"Burglar","Crowd Control",L.StunDustTier1,"stun",5},
	{"Burglar","Crowd Control",L.StunDustTier2,"stun",5},
	{"Burglar","Crowd Control",L.StunDustTier3,"stun",5},
	{"Burglar","Crowd Control",L.ExploitOpening,"knockdown",5},
	{"Burglar","Crowd Control",L.Trip,"knockdown",5},
	{"Burglar","Crowd Control",L.MarblesTier1,"knockdown",6},
	{"Burglar","Crowd Control",L.MarblesTier2,"knockdown",6},
	{"Burglar","Crowd Control",L.MarblesTier3,"knockdown",6},
	-- TODO: Check various tiers of Marbles/Stun Dust
	
	{"Burglar","Remover",L.MischievousDelight,nil,nil,{L.TrickDisable,L.TrickCounterDefence,L.TrickImprovedCounterDefence,L.TrickDustInTheEyes,L.TrickEnrage,"CC"}},
	{"Burglar","Remover",L.MischievousGlee,nil,nil,{L.TrickDisable,L.TrickCounterDefence,L.TrickImprovedCounterDefence,L.TrickDustInTheEyes,L.TrickEnrage,"CC"}},
	
	-- 2) Captain Skills
	{"Captain","Buff",L.MusterCourage},
	{"Captain","Buff",L.InHarmsWay},
	{"Captain","Buff",L.WarCry},
	{"Captain","Buff",L.BladeOfElendil},
	{"Captain","Buff",L.Motivated},
	{"Captain","Buff",L.OnGuard},
	{"Captain","Buff",L.RelentlessAttack},
	{"Captain","Buff",L.Focus},
	{"Captain","Buff",L.ShieldBrother},
	{"Captain","Buff",L.WatchfulShieldBrother},
	{"Captain","Buff",L.SongBrother},
	{"Captain","Buff",L.BladeBrother},
	{"Captain","Buff",L.ToArmsShieldBrother},
	{"Captain","Buff",L.ToArmsFellowshipShieldBrother},
	{"Captain","Buff",L.ToArmsSongBrother},
	{"Captain","Buff",L.ToArmsFellowshipSongBrother},
	{"Captain","Buff",L.ToArmsBladeBrother},
	{"Captain","Buff",L.ToArmsFellowshipBladeBrother},
	{"Captain","Buff",L.StrengthOfWillShieldBrother},
	{"Captain","Buff",L.StrengthOfWillFellowshipShieldBrother},
	{"Captain","Buff",L.StrengthOfWillSongBrother},
	{"Captain","Buff",L.StrengthOfWillFellowshipSongBrother},
	{"Captain","Buff",L.StrengthOfWillBladeBrother},
	{"Captain","Buff",L.StrengthOfWillFellowshipBladeBrother},
	{"Captain","Buff",L.RallyingCry},
	{"Captain","Buff",L.InDefenceOfMiddleEarth},
	
	{"Captain","Buff",L.DefensiveStrike,true},
	{"Captain","Buff",L.ImprovedDefensiveStrike,true},
	{"Captain","Buff",L.LastStand,true},
	
	{"Captain","Debuff",L.NobleMark,"nm",nil,{L.TellingMark,L.RevealingMark}},
	{"Captain","Debuff",L.TellingMark,"tm",nil,{L.NobleMark,L.RevealingMark}},
	{"Captain","Debuff",L.RevealingMark,"rm",nil,{L.NobleMark,L.TellingMark}},
	
	-- 3) Champion Skills
	{"Champion","Buff",L.Fervour,true,true},
	{"Champion","Buff",L.Glory,true,true},
	{"Champion","Buff",L.Ardour,true,true},
	{"Champion","Buff",L.ControlledBurn,true},
	{"Champion","Buff",L.Flurry,true},
	{"Champion","Buff",L.SuddenDefence,true},
	{"Champion","Buff",L.SeekingBlades,true},
	{"Champion","Buff",L.Adamant,true},
	{"Champion","Buff",L.Invincible,true},
	
	{"Champion","Benefit",L.EbbingIre},
	{"Champion","Benefit",L.RisingIre},
	
	-- TODO: rend debuff?
	
	-- 4) Guardian Skills
	{"Guardian","Buff",L.Protection},
	{"Guardian","Buff",L.ProtectionByTheSword},
	{"Guardian","Buff",L.ShieldWall},
	
	{"Guardian","Buff",L.GuardiansBlockStance,true,true},
	{"Guardian","Buff",L.GuardiansParryStance,true,true},
	{"Guardian","Buff",L.Overpower,true,true},
	{"Guardian","Buff",L.GuardiansThreatStance,true,true},
	{"Guardian","Buff",L.GuardiansPledge,true},
	{"Guardian","Buff",L.GuardiansWard,true},
	{"Guardian","Buff",L.ImprovedGuardiansWard,true},
	{"Guardian","Buff",L.GuardiansWardTactics,true},
	{"Guardian","Buff",L.ImprovedGuardiansWardTactics,true},
	{"Guardian","Buff",L.WarriorsBlock,true},
	{"Guardian","Buff",L.WarriorsParry,true},
	{"Guardian","Buff",L.WarriorsPower,true},
	{"Guardian","Buff",L.WarriorsThreat,true},
	-- TODO: Shield Spikes?
	
	{"Guardian","Debuff",L.Challenge,"challenge",10},
	{"Guardian","Debuff",L.ImprovedChallenge,"challenge",10},
	{"Guardian","Debuff",L.ChallengeTheDarkness,"challenge",10},
	{"Guardian","Debuff",L.ImprovedOverwhelm,"overwhelm",10},
	{"Guardian","Debuff",L.ImprovedSting,nil,nil,nil,nil,true,L.ImminentCleansing},
	{"Guardian","Debuff",L.ImminentCleansing,"ic",10,nil,true},
	
	-- 5) Hunter Skills
	{"Hunter","Buff",L.StanceStrength,true,true},
	{"Hunter","Buff",L.StancePrecision,true,true},
	{"Hunter","Buff",L.StanceEndurance,true,true},
	{"Hunter","Buff",L.BurnHot,true},
	{"Hunter","Buff",L.CoolBurn,true},
	{"Hunter","Buff",L.Fleetness,true},
	{"Hunter","Buff",L.ImprovedFleetness,true},
	{"Hunter","Buff",L.SwiftStroke,true},
	{"Hunter","Buff",L.NeedfulHaste,true},
	{"Hunter","Buff",L.HuntersArt,true},
	-- TODO: Oils?
	
	{"Hunter","Crowd Control",L.DazingBlow,"daze",5},
	{"Hunter","Crowd Control",L.ImprovedDazingBlow,"daze",5},
	{"Hunter","Crowd Control",L.DistractingShot,"daze",10},
	{"Hunter","Crowd Control",L.CryOfThePredator,"fear",15},
	{"Hunter","Crowd Control",L.BardsArrow,"fear",15},
	{"Hunter","Crowd Control",L.RainOfThorns,"root",30},
	{"Hunter","Crowd Control",L.TrapDamage,"root",30},
	-- TODO: Crafted traps?
	
	-- 6) Lore-Master Skills
	{"LoreMaster","Buff",L.AirLore},
	{"LoreMaster","Buff",L.ContinualAirLore},
	{"LoreMaster","Buff",L.SignOfPowerRighteousness},
	{"LoreMaster","Buff",L.SignOfPowerVigilance},
	{"LoreMaster","Buff",L.SignOfTheWildRage},
	{"LoreMaster","Buff",L.ImprovedSignOfTheWildRage},
	{"LoreMaster","Buff",L.SignOfTheWildProtection},
	
	{"LoreMaster","Debuff",L.GustOfWind,"gow",120},
	{"LoreMaster","Debuff",L.FireLore,"firelore",30},
	{"LoreMaster","Debuff",L.WindLore,"windlore",30},
	{"LoreMaster","Debuff",L.FrostLore,"frostlore",30},
	{"LoreMaster","Debuff",L.AncientCraft,"ancientcraft",30},
	{"LoreMaster","Debuff",L.SignOfPowerCommand,"sopc",60},
	{"LoreMaster","Debuff",L.ImprovedSignOfPowerCommand,"sopc",60},
	{"LoreMaster","Debuff",L.SignOfPowerSeeAllEnds,"sopsae",15},
	{"LoreMaster","Debuff",L.CrackedEarth,"crackedearth",10,nil,nil,nil,L.CrackedEarth.." "..L.Root,10},
	
	{"LoreMaster","Crowd Control",L.BlindingFlash,"daze",30},
	{"LoreMaster","Crowd Control",L.ImprovedBlindingFlash,"daze",30},
	{"LoreMaster","Crowd Control",L.BaneFlare,"daze",15},
	{"LoreMaster","Crowd Control",L.CrackedEarth.." "..L.Root,"root",30},
	{"LoreMaster","Crowd Control",L.HerbLore,"root",30},
	
	-- 7) Minstrel Skills
	{"Minstrel","Buff",L.AnthemOfWar},
	{"Minstrel","Buff",L.AnthemOfTheFreePeoples},
	{"Minstrel","Buff",L.AnthemOfProwess},
	{"Minstrel","Buff",L.AnthemOfComposure},
	{"Minstrel","Buff",L.TheMelodyOfBattle},
	{"Minstrel","Buff",L.InspireFellows},
	{"Minstrel","Buff",L.SoliloquyOfSpirit},
	{"Minstrel","Buff",L.ImprovedChordOfSalvation},
	{"Minstrel","Buff",L.TaleOfHeroism},
	{"Minstrel","Buff",L.TaleOfBattle},
	{"Minstrel","Buff",L.TaleOfWarding},
	{"Minstrel","Buff",L.TaleOfWardingAndHope},
	{"Minstrel","Buff",L.TaleOfFrostAndFlame},
	{"Minstrel","Buff",L.TaleOfFrostAndFlamesBattle}, -- TODO: this needed?
	{"Minstrel","Buff",L.TaleOfWardingAndHeroism}, -- TODO: this needed?
	{"Minstrel","Buff",L.SymphonyOfTheHopefulHeart},
	
	{"Minstrel","Buff",L.Harmony,true,true},
	{"Minstrel","Buff",L.WarSpeech,true,true},
	{"Minstrel","Buff",L.AnthemOfCompassion,true},
	{"Minstrel","Buff",L.AnthemOfTheThirdAge,true},
	{"Minstrel","Buff",L.AnthemOfTheThirdAgeWarSpeech,true},
	{"Minstrel","Buff",L.AnthemOfTheThirdAgeHarmony,true},
	{"Minstrel","Buff",L.MinorBallad,true},
	{"Minstrel","Buff",L.MajorBallad,true},
	{"Minstrel","Buff",L.PerfectBallad,true},
	{"Minstrel","Buff",L.StillAsDeath,true},
	
	{"Minstrel","Crowd Control",L.SongOfTheDead,"daze",30},
	{"Minstrel","Crowd Control",L.InvocationOfElbereth,"fear",15},
	
	-- 8) Rune-Keeper Skills
	{"RuneKeeper","Buff",L.DoNotFallToStorm},
	{"RuneKeeper","Buff",L.DoNotFallToFlame},
	{"RuneKeeper","Buff",L.DoNotFallToWinter},
	{"RuneKeeper","Buff",L.DoNotFallThisDay},
	{"RuneKeeper","Buff",L.ShallNotFallThisDay},
	{"RuneKeeper","Buff",L.PreludeToHope},
	{"RuneKeeper","Buff",L.RuneOfRestoration},
	{"RuneKeeper","Buff",L.WritOfHealthTier1},
	{"RuneKeeper","Buff",L.WritOfHealthTier2},
	{"RuneKeeper","Buff",L.WritOfHealthTier3},
	{"RuneKeeper","Buff",L.GloriousForeshadowing},
	{"RuneKeeper","Buff",L.WondrousForeshadowing},
	{"RuneKeeper","Buff",L.AllFatesEntwined},
	{"RuneKeeper","Buff",L.OurFatesEntwined},
	
	-- NB: Don't think we can accurately keep track of tiered writs (debuffs)
	
	-- TODO: RK dazes?
	
	-- 9) Warden Skills
	{"Warden","Buff",L.Conviction},
	
	{"Warden","Buff",L.DeterminationStance,true,true},
	{"Warden","Buff",L.Conservation,true,true},
	{"Warden","Buff",L.Recklessness,true,true},
	{"Warden","Buff",L.WayOfTheWarden,true},
	{"Warden","Buff",L.ShieldBashBlock,true},
	{"Warden","Buff",L.WallOfSteelParry,true},
	{"Warden","Buff",L.AdroitManoeuvre,true},
	{"Warden","Buff",L.WardensTriumph,true},
	{"Warden","Buff",L.DefensiveStrikeBlock,true},
	{"Warden","Buff",L.Persevere,true},
	{"Warden","Buff",L.ShieldDefence,true},
	{"Warden","Buff",L.ShieldMastery,true},
	{"Warden","Buff",L.ShieldTactics,true},
	{"Warden","Buff",L.DanceOfBattleEvade,true},
	{"Warden","Buff",L.TacticallySound,true},
	{"Warden","Buff",L.T1HealOverTime,true},
	{"Warden","Buff",L.T2HealOverTime,true},
	{"Warden","Buff",L.T3HealOverTime,true},
	{"Warden","Buff",L.T4HealOverTime,true},
	-- TODO: Shield Spikes/Oils?
	
	-- 10) Racial Skills
	{"Racial","Buff",L.DutyBound},
	{"Racial","Buff",L.DwarfEndurance},
	
	-- Other
	{"None","Crowd Control",L.StunImmunity,"stunimmunity",10}	-- NB: No comma after the last skill
	
}

local genericSkillIcon = "CombatAnalysis/Resources/debuff_default.tga";




-->> Do not modify code below this line <<--

-- Build indexes into the skill list for quick access to skill info

_G.allSkills = {}
_G.tempMoraleSkills = {}
_G.skillsByClass = {}

for _,skillInfo in pairs(skillList) do
	local class = skillInfo[1];     -- The class which uses the skill
	local skillType = skillInfo[2]; -- TempMorale, Buff, Debuff, or Crowd Control
	local name = skillInfo[3];      -- The name of the skill (see note at the top of this file)
	
	if (skillType == "TempMorale") then
		-- extract temp morale skill name info
		local logName = name[1];
		local effectName = name[2];
		
		-- add temp morale indexes
		if (tempMoraleSkills[logName] == nil) then tempMoraleSkills[logName] = {} end
		if (tempMoraleSkills[effectName] == nil) then tempMoraleSkills[effectName] = {} end
		
		tempMoraleSkills[logName][effectName] = true;
		tempMoraleSkills[effectName][logName] = true;
	else
		-- add skill indexes
		if (skillsByClass[class] == nil) then skillsByClass[class] = {} end
		if (skillsByClass[class][skillType] == nil) then skillsByClass[class][skillType] = {} end
		
		local skillIcon;
		if (skillInfo[4] == nil) then
			skillIcon = genericSkillIcon;
		elseif (type(skillInfo[4]) == "string") then
			skillIcon = "CombatAnalysis/Resources/"..string.lower(string.gsub(skillType," ","")).."_"..string.lower(skillInfo[4])..".tga"
		else
			skillIcon = skillInfo[4];
		end
		
		allSkills[name] = {skillType,skillIcon,skillInfo[5],skillInfo[6],skillInfo[7],skillInfo[8],(skillType == "Crowd Control" and skillInfo[4] or skillInfo[9]),skillInfo[10]};
		skillsByClass[class][skillType][name] = {skillIcon,skillInfo[5],skillInfo[6],skillInfo[7],skillInfo[8],(skillType == "Crowd Control" and skillInfo[4] or skillInfo[9]),skillInfo[10]};
	end
end
